<?php

namespace Btravel\Object\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Object\Models\Club;

class ClubPolicy
{

    /**
     * Determine if the given user can view the club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function view(UserPolicy $user, Club $club)
    {
        if ($user->canDo('object.club.view') && $user->isAdmin()) {
            return true;
        }

        return $club->user_id == user_id() && $club->user_type == user_type();
    }

    /**
     * Determine if the given user can create a club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('object.club.create');
    }

    /**
     * Determine if the given user can update the given club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function update(UserPolicy $user, Club $club)
    {
        if ($user->canDo('object.club.edit') && $user->isAdmin()) {
            return true;
        }

        return $club->user_id == user_id() && $club->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Club $club)
    {
        return $club->user_id == user_id() && $club->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Club $club)
    {
        if ($user->canDo('object.club.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given club.
     *
     * @param UserPolicy $user
     * @param Club $club
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Club $club)
    {
        if ($user->canDo('object.club.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
