<?php

namespace Btravel\Objects\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Objects\Models\Hotel;

class HotelPolicy
{

    /**
     * Determine if the given user can view the hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hotel $hotel)
    {
        if ($user->canDo('objects.hotel.view') && $user->isAdmin()) {
            return true;
        }

        return $hotel->user_id == user_id() && $hotel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('objects.hotel.create');
    }

    /**
     * Determine if the given user can update the given hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hotel $hotel)
    {
        if ($user->canDo('objects.hotel.edit') && $user->isAdmin()) {
            return true;
        }

        return $hotel->user_id == user_id() && $hotel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hotel $hotel)
    {
        return $hotel->user_id == user_id() && $hotel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hotel $hotel)
    {
        if ($user->canDo('objects.hotel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hotel.
     *
     * @param UserPolicy $user
     * @param Hotel $hotel
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hotel $hotel)
    {
        if ($user->canDo('objects.hotel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
