<?php

namespace Btravel\Objects\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Objects\Models\Ship;

class ShipPolicy
{

    /**
     * Determine if the given user can view the ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function view(UserPolicy $user, Ship $ship)
    {
        if ($user->canDo('objects.ship.view') && $user->isAdmin()) {
            return true;
        }

        return $ship->user_id == user_id() && $ship->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('objects.ship.create');
    }

    /**
     * Determine if the given user can update the given ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function update(UserPolicy $user, Ship $ship)
    {
        if ($user->canDo('objects.ship.edit') && $user->isAdmin()) {
            return true;
        }

        return $ship->user_id == user_id() && $ship->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Ship $ship)
    {
        return $ship->user_id == user_id() && $ship->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Ship $ship)
    {
        if ($user->canDo('objects.ship.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ship.
     *
     * @param UserPolicy $user
     * @param Ship $ship
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Ship $ship)
    {
        if ($user->canDo('objects.ship.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
