<?php

namespace Btravel\Objects\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Objects\Models\Objects;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Objects\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/objects/ship/*')) {
            Route::bind('ship', function ($ship) {
                $shiprepo = $this->app->make('Btravel\Objects\Interfaces\ShipRepositoryInterface');
                return $shiprepo->findorNew($ship);
            });
        }

        if (Request::is('*/objects/hotel/*')) {
            Route::bind('hotel', function ($hotel) {
                $hotelrepo = $this->app->make('Btravel\Objects\Interfaces\HotelRepositoryInterface');
                return $hotelrepo->findorNew($hotel);
            });
        }

        if (Request::is('*/objects/club/*')) {
            Route::bind('club', function ($club) {
                $clubrepo = $this->app->make('Btravel\Objects\Interfaces\ClubRepositoryInterface');
                return $clubrepo->findorNew($club);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
