<?php

namespace Btravel\Object\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Object\Models\Object;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Object\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/object/ship/*')) {
            Route::bind('ship', function ($ship) {
                $shiprepo = $this->app->make('Btravel\Object\Interfaces\ShipRepositoryInterface');
                return $shiprepo->findorNew($ship);
            });
        }
        if (Request::is('*/object/hotel/*')) {
            Route::bind('hotel', function ($hotel) {
                $hotelrepo = $this->app->make('Btravel\Object\Interfaces\HotelRepositoryInterface');
                return $hotelrepo->findorNew($hotel);
            });
        }
        if (Request::is('*/object/club/*')) {
            Route::bind('club', function ($club) {
                $clubrepo = $this->app->make('Btravel\Object\Interfaces\ClubRepositoryInterface');
                return $clubrepo->findorNew($club);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
